@@ -735,8 +735,6 @@ class MibAnalyzer extends Asn1Analyzer {
      * @param node           the node being exited
      * 
      * @return the node to add to the parse tree
-     * 
-     * @throws ParseException if the node analysis discovered errors
      */
     protected Node exitEnumeratedType(Production node) {
         // TODO: implement enumerated type support
@@ -2745,28 +2743,6 @@ class MibAnalyzer extends Asn1Analyzer {
         }
     }
 
-    /**
-     * Returns all the child values for a node.
-     *
-     * @param node           the parse tree node
-     *
-     * @return a list with all the child node values
-     */
-    private ArrayList getChildValues(Node node) {
-        ArrayList  result = new ArrayList();
-        Node       child;
-        ArrayList  values;
-                                                                                
-        for (int i = 0; i < node.getChildCount(); i++) {
-            child = node.getChildAt(i);
-            values = child.getAllValues();
-            if (values != null) {
-                result.addAll(values);
-            }
-        }
-        return result;
-    }
-    
     /**
      * Returns the location of a specified node.
      * 
